==> zio-aws-kafka_3-5.17.104.10-sources.jar: zio/aws/kafka/model/DeleteConfigurationRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteConfigurationRequest(arn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest = {
    import DeleteConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest
      .builder()
      .arn(__string.unwrap(arn): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.DeleteConfigurationRequest.ReadOnly =
    zio.aws.kafka.model.DeleteConfigurationRequest.wrap(buildAwsValue())
}
object DeleteConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.DeleteConfigurationRequest =
      zio.aws.kafka.model.DeleteConfigurationRequest(arn)
    def arn: __string
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest
  ) extends zio.aws.kafka.model.DeleteConfigurationRequest.ReadOnly {
    override val arn: __string =
      zio.aws.kafka.model.primitives.__string(impl.arn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest
  ): zio.aws.kafka.model.DeleteConfigurationRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_3-5.17.146.1-sources.jar: zio/aws/kafka/model/DeleteConfigurationRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteConfigurationRequest(arn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest = {
    import DeleteConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest
      .builder()
      .arn(arn: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.DeleteConfigurationRequest.ReadOnly =
    zio.aws.kafka.model.DeleteConfigurationRequest.wrap(buildAwsValue())
}
object DeleteConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.DeleteConfigurationRequest =
      zio.aws.kafka.model.DeleteConfigurationRequest(arn)
    def arn: __string
    def getArn: ZIO[Any, Nothing, __string] = ZIO.succeed(arn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest
  ) extends zio.aws.kafka.model.DeleteConfigurationRequest.ReadOnly {
    override val arn: __string = impl.arn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.DeleteConfigurationRequest
  ): zio.aws.kafka.model.DeleteConfigurationRequest.ReadOnly = new Wrapper(impl)
}
